@@ -1,4 +1,5 @@
 """Module for systematically evaluating different combinations of sklearn pipelines."""
+import functools
 import pickle
 from itertools import product
 from pathlib import Path
@@ -140,7 +141,7 @@ class SklearnPipelinePermuter:
         self.hyper_search_dict: Dict[str, Dict[str, Any]] = {}
         """Dictionary specifying the selected hyperparameter search method for each estimator."""
 
-        self.param_searches: Dict[Tuple[str, str], pd.DataFrame] = {}
+        self.param_searches: Dict[Tuple[str, str], Dict[str, Any]] = {}
         """Dictionary with parameter search results for each pipeline step combination."""
 
         self.results: Optional[pd.DataFrame] = None
@@ -235,6 +236,7 @@ class SklearnPipelinePermuter:
         outer_cv: BaseCrossValidator,
         inner_cv: BaseCrossValidator,
         scoring: Optional[str_t] = None,
+        use_cache: Optional[bool] = True,
         **kwargs,
     ):
         """Run fit for all pipeline combinations and sets of parameters.
@@ -254,6 +256,9 @@ class SklearnPipelinePermuter:
             Cross-validation object determining the cross-validation splitting strategy of the hyperparameter search.
         scoring : str, optional
             A str specifying the scoring metric to use for evaluation.
+        use_cache : bool, optional
+            ``True`` to cache fitted transformer instances of the pipeline in a caching directory
+            (can be provided by the additional parameter ``cachedir_name``), ``False`` otherwise. Default: ``True``
         **kwargs :
             Additional arguments that are passed to
             :func:`~biopsykit.classification.model_selection.nested_cv_parameter_search` and the hyperparameter search
@@ -266,7 +271,12 @@ class SklearnPipelinePermuter:
         kwargs.setdefault("n_jobs", -1)
         kwargs.setdefault("verbose", 1)
         kwargs.setdefault("error_score", "raise")
-        cachedir_name = kwargs.pop("cachedir_name", "cachedir")
+
+        # Create a temporary folder to store the transformers of the pipeline
+        location = kwargs.pop("cachedir_name", "cachedir")
+        memory = None
+        if use_cache:
+            memory = Memory(location=location, verbose=0)
 
         if scoring is None:
             scoring = "accuracy"
@@ -277,10 +287,6 @@ class SklearnPipelinePermuter:
             refit = scoring
         self.refit = refit
 
-        # Create a temporary folder to store the transformers of the pipeline
-        location = cachedir_name
-        memory = Memory(location=location, verbose=0)
-
         for model_combination in tqdm(self.model_combinations):
             if model_combination in self.param_searches:
                 # continue if we already tried this combination
@@ -326,10 +332,12 @@ class SklearnPipelinePermuter:
                 print("")
             print("")
 
-        # Delete the temporary cache before exiting
-        memory.clear(warn=False)
-        rmtree(location)
+        if use_cache:
+            # Delete the temporary cache before exiting
+            memory.clear(warn=False)
+            rmtree(location)
 
+    @functools.lru_cache(maxsize=5)
     def pipeline_score_results(self) -> pd.DataFrame:
         """Return parameter search results for each pipeline combination.
 
@@ -343,7 +351,7 @@ class SklearnPipelinePermuter:
             return self.results
         if len(self.param_searches) == 0:
             raise AttributeError(
-                "No results available because pipelines were not fitted! " "Call `SklearnPipelinePermuter.fit()` first."
+                "No results available because pipelines were not fitted! Call `SklearnPipelinePermuter.fit()` first."
             )
 
         gs_param_list = []
@@ -389,6 +397,7 @@ class SklearnPipelinePermuter:
         _assert_file_extension(file_path, ".csv")
         self.results.to_csv(file_path)
 
+    @functools.lru_cache(maxsize=5)
     def mean_pipeline_score_results(self) -> pd.DataFrame:
         """Compute mean score results for each pipeline combination.
 
@@ -398,6 +407,9 @@ class SklearnPipelinePermuter:
             dataframe with mean score results for each pipeline combination and each parameter combination,
             sorted by the highest mean score.
 
+        .. note ::
+            The "mean_test_xx" columns
+
         """
         score_results = self.pipeline_score_results()
         score_summary_mean = (
